@@ -262,7 +262,7 @@ class ApplicationReportMixin:
         if not access.check("r"):
             return httputils.NOT_ALLOWED
         try:
-            xml_content = self._read_xml_content(environ)
+            xml_content = self._read_xml_request_body(environ)
         except RuntimeError as e:
             logger.warning(
                 "Bad REPORT request on %r: %s", path, e, exc_info=True)
@@ -290,4 +290,4 @@ class ApplicationReportMixin:
                 logger.warning(
                     "Bad REPORT request on %r: %s", path, e, exc_info=True)
                 return httputils.BAD_REQUEST
-            return (status, headers, self._write_xml_content(xml_answer))
+            return status, headers, self._xml_response(xml_answer)
